@@ -1,16 +1,16 @@
 module Fog
-  module Parsers
-    module Storage
-      module Google
+  module Google
+    module Parsers
+      module Storage
         class GetBucketVersioning < Fog::Parsers::Base
           def reset
-            @response = { 'VersioningConfiguration' => {} }
+            @response = { "VersioningConfiguration" => {} }
           end
 
           def end_element(name)
             case name
-            when 'Status'
-              @response['VersioningConfiguration'][name] = value
+            when "Status"
+              @response["VersioningConfiguration"][name] = value
             end
           end
         end
