@@ -40,16 +40,16 @@ module Fog
         begin
           # TODO: google-api-client is in gemspec now, re-assess if this initialization logic is still needed
           require "google/apis/monitoring_#{Fog::Google::Monitoring::GOOGLE_MONITORING_API_VERSION}"
-          require "google/apis/compute_#{Fog::Compute::Google::GOOGLE_COMPUTE_API_VERSION}"
-          require "google/apis/dns_#{Fog::DNS::Google::GOOGLE_DNS_API_VERSION}"
+          require "google/apis/compute_#{Fog::Google::Compute::GOOGLE_COMPUTE_API_VERSION}"
+          require "google/apis/dns_#{Fog::Google::DNS::GOOGLE_DNS_API_VERSION}"
           require "google/apis/pubsub_#{Fog::Google::Pubsub::GOOGLE_PUBSUB_API_VERSION}"
           require "google/apis/sqladmin_#{Fog::Google::SQL::GOOGLE_SQL_API_VERSION}"
-          require "google/apis/storage_#{Fog::Storage::GoogleJSON::GOOGLE_STORAGE_JSON_API_VERSION}"
-          require "google/apis/iamcredentials_#{Fog::Storage::GoogleJSON::GOOGLE_STORAGE_JSON_IAM_API_VERSION}"
+          require "google/apis/storage_#{Fog::Google::StorageJSON::GOOGLE_STORAGE_JSON_API_VERSION}"
+          require "google/apis/iamcredentials_#{Fog::Google::StorageJSON::GOOGLE_STORAGE_JSON_IAM_API_VERSION}"
           require "googleauth"
-        rescue LoadError => error
+        rescue LoadError => e
           Fog::Errors::Error.new("Please install the google-api-client (>= 0.9) gem before using this provider")
-          raise error
+          raise e
         end
 
         validate_client_options(options)
@@ -67,31 +67,36 @@ module Fog
           ::Google::Apis.logger.level = ::Logger::DEBUG
         end
 
-        auth = nil
-
-        if options[:google_json_key_location] || options[:google_json_key_string]
-          auth = process_key_auth(options)
-        elsif options[:google_auth]
-          auth = options[:google_auth]
-        elsif options[:google_application_default]
-          auth = process_application_default_auth(options)
-        else
-          auth = process_fallback_auth(options)
+        initialize_auth(options).tap do |auth|
+          ::Google::Apis::RequestOptions.default.authorization = auth
         end
+      end
 
-        ::Google::Apis::RequestOptions.default.authorization = auth
-        auth
+      def initialize_auth(options)
+        if options[:google_json_key_location] || options[:google_json_key_string]
+          process_key_auth(options)
+        elsif options[:google_auth]
+          options[:google_auth]
+        elsif options[:google_application_default]
+          process_application_default_auth(options)
+        else
+          process_fallback_auth(options)
+        end
       end
 
       ##
       # Applies given options to the client instance
       #
       # @param [Google::Apis::Core::BaseService] service API service client instance
-      # @param [Hash] options (all ignored a.t.m., except :google_client_options)
+      # @param [Hash] options (:universe_domain, :google_client_options)
       # @return [void]
       def apply_client_options(service, options = {})
+        universe_domain = universe_domain_from_options(options)
+        service.universe_domain = universe_domain if universe_domain
+
         google_client_options = options[:google_client_options]
         return if google_client_options.nil? || google_client_options.empty?
+
         (service.client_options.members & google_client_options.keys).each do |option|
           service.client_options[option] = google_client_options[option]
         end
@@ -155,12 +160,22 @@ module Fog
 
       private
 
+      # Helper method to get universe domain from options or environment
+      #
+      # @param [Hash] options - client options hash
+      # @return [String, nil] - universe domain or nil
+      def universe_domain_from_options(options)
+        options[:universe_domain] || ENV["GOOGLE_CLOUD_UNIVERSE_DOMAIN"]
+      end
+
       # Helper method to process application default authentication
       #
       # @param [Hash]  options - client options hash
       # @return [Google::Auth::DefaultCredentials] - google auth object
       def process_application_default_auth(options)
-        ::Google::Auth.get_application_default(options[:google_api_scope_url])
+        google_options = options.slice(:universe_domain)
+        credentials = ::Google::Auth.get_application_default(options[:google_api_scope_url], google_options)
+        credentials
       end
 
       # Helper method to process fallback authentication
@@ -175,7 +190,7 @@ module Fog
         )
         begin
           return process_application_default_auth(options)
-        rescue
+        rescue StandardError
           raise Fog::Errors::Error.new(
             "Fallback auth failed, could not configure authentication for Fog client.\n" \
               "Check your auth options, must be one of:\n" \
@@ -201,10 +216,14 @@ module Fog
 
         validate_json_credentials(json_key)
 
-        ::Google::Auth::ServiceAccountCredentials.make_creds(
+        credentials = ::Google::Auth::ServiceAccountCredentials.make_creds(
           :json_key_io => StringIO.new(json_key),
           :scope => options[:google_api_scope_url]
         )
+
+        universe_domain = universe_domain_from_options(options)
+        credentials.universe_domain = universe_domain if universe_domain && credentials.respond_to?(:universe_domain=)
+        credentials
       end
 
       # Helper method to sort out deprecated and missing auth options
